..
  SPDX-FileCopyrightText: 2023 Carmen Bianca BAKKER <carmen@carmenbianca.eu>

  SPDX-License-Identifier: CC-BY-SA-4.0 OR GPL-3.0-or-later


Protokolo documentation
=======================

Protokolo is a change log generator.

Protokolo allows you to maintain your change log fragments in separate files,
and then finally aggregate them into a new section in CHANGELOG just before
release.

Table of contents
-----------------

.. toctree::
   :maxdepth: 2

   Overview<readme>
   reference
   man/index

API reference
-------------
.. toctree::
   :maxdepth: 3

   API<api/protokolo>

Change log
----------
.. toctree::
   :maxdepth: 2

   history

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
